@@ -16,11 +16,11 @@ Net::SMTP::Bulk - NonBlocking batch SMTP using Net::SMTP interface
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 
 
@@ -40,7 +40,7 @@ This method was created first, it was used on a server with little ram while try
 
 The email sending process is in order, which means it will call the MAIL FROM, RCPT TO and etc commands for all emails in the batch at the same time. If 1 email fails in a batch, it is thrown out of the batch and it is up to you to figure out how to handle it through the Callbacks. It is possible for a single command to mess up the entire batch though.
 
-Other differences: Uses Authen::SASL for AUTH, SSL/STARTTLS handshake is negotiated by a workaround
+Other differences: SSL/STARTTLS handshake is negotiated by a workaround
 
     use Net::SMTP::Bulk::Coro;
 
@@ -54,7 +54,7 @@ How it works is, you send all the emails to the module and once the quit command
 
 This means if you have a million emails, all those million emails are going into ram.
 
-Other differences: Uses my own implementation for AUTH (Supports: LOGIN only), SSL/STARTTLS handshake is negotiated AnyEvent::TLS 
+Other differences: SSL/STARTTLS handshake is negotiated AnyEvent::TLS 
 
     use Net::SMTP::Bulk::AnyEvent;
 
@@ -66,8 +66,6 @@ The answer 9/10 times, METHOD 2: AnyEvent only. Why? Because I am using it. Whil
 
 If your worry about using Method 2 comes down to ram, there are workarounds such as having it send in batches of say 1000. And while I can make Method 2 work like Method 1 fully, at this point I have no plan to. So if you are constrained by ram, try dividing up the emails in 1000 at a time for Method 2. If that doesn't work, Method 1 is your way point.
 
-Another caveat for Method 2 is so far it only supports LOGIN authentication. I plan to implement others in the future. Again, if you have a request for it to be prioritized, make a request in the bug reports.
-
 Both Methods should work for the most part. Just again, Method 2 will see more love at this point.
 
 
@@ -90,7 +88,7 @@ Hello - The domain name you wish to connect to (default: [same as server])
 
 Debug - Debug information (0-10 depending on level. Higher level contains all lower levels) (default: 0, 0 - disabled, 5 - summary, 7 - hangs/fails, 8 - passes, 10 - full details) OPTIONAL
 
-DebugPath - Set to default Debug Path. use [HOST] and [THREAD] for deeper control of output OPTIONAL
+DebugPath - Set to default Debug Path. use [HOST] and [THREAD] for deeper control of output. Dates can also be appended via [YYYY] = year, [MM] = month, [DD] = day, [WK] = week, [hh] = hour, [mm] = minute OPTIONAL
 
 Secure - If you wish to use a secure connection. ( default: 0, 0 - None, 1 - SSL [no verify], 2 - SSL [verify], 3 - STARTTLS [no verify], 4 - STARTTLS [verify]) OPTIONAL [Requires Net::SSLeay]
 
@@ -100,12 +98,16 @@ Encode - Encode socket( 1: utf8 )
 
 Timeout - Amount of seconds until it gives up on the session and attempts to reconnect ( defaukt: 60  ) OPTIONAL
 
+Hosts - An ARRAY containing a list of HASH reference of Hosts OPTIONAL
+
 GlobalTimeout - (Method 2 only) Amount of seconds for no activity on any thread. If no activity is seen on any thread, it will reconnect on all threads. Keep in mind the delays you plan to use for Sleep and Retry. ( default: 120 ) OPTIONAL
 
 Sleep - (Method 2 only) A HASH that sets a sleep timer in seconds for reconnect attempts. ( Default: Hang=>0, Fail => 0 ) CAVEAT: Since a timer is used the last second is not reliable, so if you set a timer of 30 seconds, it can be anywhere between 29-30 seconds. OPTIONAL
 
 Retry - (Method 2 only) Amount of retries until it gives up. ( default: Hang=>1, GlobalHang => 1, Fail => 5 ) Put 0 for unlimited. OPTIONAL
 
+Auth - (Method 2 only) An ARRAY containing AUTH details. ( eg. ['AUTO','user','pass'] or to force a mechanism such as LOGIN ['LOGIN','user','pass'] ) OPTIONAL
+
 Callbacks - You can supply callback functions on certain conditions, these conditions include: OPTIONAL
 
 Method1:
@@ -145,7 +147,7 @@ You can supply multiple hosts in an array.
 
 =head2 auth( [ MECHANISM,] USERNAME, PASSWORD  )
 
-*Requires Authen::SASL for Method 1, not for Method 2.
+*Requires Authen::SASL
 
 =head2 mail( ADDRESS )
 
@@ -159,7 +161,9 @@ You can supply multiple hosts in an array.
 
 =head2 reconnect(  )
 
-=head2 quit(  )
+=head2 quit( [ID] )
+
+*ID is Method2 only and is an optional field. It helps you track the ID through debugging. It defaults to epoch time if not passed.
 
 =head1 CAVEATS
 
