@@ -6,7 +6,17 @@ use AnyEvent::Socket;
 use MIME::Base64;
 use Encode;
 
+=head1 NAME
 
+Net::SMTP::Bulk::Coro - NonBlocking batch SMTP using Net::SMTP interface cia AnyEvent
+
+=head1 VERSION
+
+Version 0.21
+
+=cut
+
+our $VERSION = '0.21';
 
 =head2 new(%options, Hosts=>[\%options2,\%options3])
 
@@ -99,16 +109,23 @@ sub auth {
     my $k=shift||$self->{last}[0];
     
     
-    #if ( !exists($self->{auth}{ $k->[0] }{ $k->[1] }[0]) ) {
+    if ( !defined($type) and exists($self->{auth}{ $k->[0] }{ $k->[1] }[0])) {
         
     
+    } elsif ( !defined($pass) or ref($pass) eq 'ARRAY' ) {
+        $k=$pass if ref($pass) eq 'ARRAY';
+        $self->{auth}{ $k->[0] }{ $k->[1] }=['AUTO',$type,$user];
+
+    } else {
+        $self->{auth}{ $k->[0] }{ $k->[1] }=[$type,$user,$pass];
+    }
+    
     
-     $self->{auth}{ $k->[0] }{ $k->[1] }=[$type,$user,$pass];
     
  # print "GOTHERE($self->{last}[0][0]){ $k->[0] }{ $k->[1] }\n";
-    if ( $self->{status_code}{ $k->[0] }{ $k->[1] } == 250 and $self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'HEADER' and $self->{stage}{ $k->[0] }{ $k->[1] }[1] == 1 ) {
-                $self->_AUTH($k);
-    }
+    #if ( $self->{status_code}{ $k->[0] }{ $k->[1] } == 250 and $self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'HEADER' and $self->{stage}{ $k->[0] }{ $k->[1] }[1] == 1 ) {
+    #            $self->_AUTH($k);
+    #}
     
     #}
     
@@ -182,8 +199,8 @@ sub dataend {
 
 
 sub quit {
-    my $self=shift;
-    
+    my $self = shift;
+    my $id = shift || time;    
     
     my $timer;
     
@@ -236,7 +253,7 @@ sub quit {
                              );
     }
     
-    my $id=time;
+
     my $total=0;
     foreach my $h ( keys(%{ $self->{threads} })  ) {
         foreach my $t ( 0..$self->{threads}{ $h } ) {
@@ -359,15 +376,18 @@ sub _PREPARE {
        
         foreach my $t ( 0..$self->{threads}{ $new{Host} } ) {
             if ( exists($self->{debug_path}) ) {
-                my $path=''.$self->{debug_path};
+                my $path=$self->_STRFTIME(''.$self->{debug_path},time);
                 $path=~s/\[HOST\]/$new{Host}/gs;
                 $path=~s/\[THREAD\]/$t/gs;
+                
+                $self->_MKDIRF($path);
                 open( $self->{debug_fh}{ $new{Host}.':'.$t } , '>>'.$path );
                 binmode( $self->{debug_fh}{ $new{Host}.':'.$t } , ':utf8' );
             }
 
             
-            $self->{auth}{ $new{Host} }{$t}=[0,''];
+            $self->{auth}{ $new{Host} }{$t}=$new{Auth}||[0,''];
+            $self->{objects}{ $new{Host} }{$t}={};
             $self->{queue}{ $new{Host} }{$t}=[];
             $self->{queue_size}{ $new{Host} }{$t}=0;
             $self->{stage}{ $new{Host} }{ $t }=['BEGIN',0];
@@ -388,15 +408,15 @@ sub _PREPARE {
         }
         
         
-=head2        
-        foreach my $t ( 0..$self->{threads}{ $new{Host} } ) {
-            $self->_HELO([$new{Host},$t]);
-        }
-        foreach my $t ( 0..$self->{threads}{ $new{Host} } ) {
-            $self->_READ([$new{Host},$t]);
-            $self->_HEADER([$new{Host},$t]);
-        }
-=cut
+      
+        #foreach my $t ( 0..$self->{threads}{ $new{Host} } ) {
+        #    $self->_HELO([$new{Host},$t]);
+        #}
+        #foreach my $t ( 0..$self->{threads}{ $new{Host} } ) {
+        #    $self->_READ([$new{Host},$t]);
+        #    $self->_HEADER([$new{Host},$t]);
+        #}
+
     
     }
 }
@@ -559,26 +579,35 @@ sub _AUTH {
     my $k=shift;
     
     if ($self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'AUTH' ) {
-        
-        if ($self->{auth}{ $k->[0] }{ $k->[1] }[0] eq 'LOGIN') {
-            
-            if ( $self->{status_text}{ $k->[0] }{ $k->[1] } eq 'VXNlcm5hbWU6' ) {
-                my $temp=MIME::Base64::encode_base64($self->{auth}{ $k->[0] }{ $k->[1] }[1]);
-                $temp=~s/[\r\n]//gs;
-                $self->_WRITE($k,$temp);
-                
-            } elsif ( $self->{status_text}{ $k->[0] }{ $k->[1] } eq  'UGFzc3dvcmQ6' ) {
-                my $temp=MIME::Base64::encode_base64($self->{auth}{ $k->[0] }{ $k->[1] }[2]);
-                $temp=~s/[\r\n]//gs;
-                $self->_WRITE($k,$temp);  
+
+        if ( $self->{stage}{ $k->[0] }{ $k->[1] }[1] == 1) {
+            if (  my $str = $self->{objects}{ $k->[0] }{ $k->[1] }{sasl_client}->client_start()  ) {
+                $self->_WRITE($k,MIME::Base64::encode_base64($str, ''));
+                $self->{stage}{ $k->[0] }{ $k->[1] }[1]++;
+                return;
             }
+        }      
             
-            
-            
-        }
+        my $msg = MIME::Base64::decode_base64($self->{status_text}{ $k->[0] }{ $k->[1] });
+        $self->_WRITE($k, MIME::Base64::encode_base64($self->{objects}{ $k->[0] }{ $k->[1] }{sasl_client}->client_step( $msg ),'') );
+        $self->{stage}{ $k->[0] }{ $k->[1] }[1]++;   
     } else {
+        require Authen::SASL;
+       
+        my $mech=( $self->{auth}{ $k->[0] }{ $k->[1] }[0] eq 'AUTO' ) ? uc(join(' ',@{$self->{header}{ $k->[0] }{ $k->[1] }{auth}})) : $self->{auth}{ $k->[0] }{ $k->[1] }[0];
+
+        $self->{objects}{ $k->[0] }{ $k->[1] }{sasl} = Authen::SASL->new (
+            mechanism => $mech,
+            callback => {
+                user => $self->{auth}{ $k->[0] }{ $k->[1] }[1],
+                pass => $self->{auth}{ $k->[0] }{ $k->[1] }[2],
+                authname => $self->{auth}{ $k->[0] }{ $k->[1] }[1],
+            }
+        );
+
+        $self->{objects}{ $k->[0] }{ $k->[1] }{sasl_client} = $self->{objects}{ $k->[0] }{ $k->[1] }{sasl}->client_new("smtp", $k->[0],1);
         $self->{stage}{ $k->[0] }{ $k->[1] }=['AUTH',0];
-        $self->_WRITE($k,'AUTH '.$self->{auth}{ $k->[0] }{ $k->[1] }[0]);
+        $self->_WRITE($k,'AUTH '.$self->{objects}{ $k->[0] }{ $k->[1] }{sasl_client}->mechanism);
         $self->{stage}{ $k->[0] }{ $k->[1] }=['AUTH',1];
         
     }
@@ -739,9 +768,9 @@ sub _READ {
                 }
                
                
-            } elsif ($self->{status_code}{ $k->[0] }{ $k->[1] } == 334 and $self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'AUTH' and $self->{stage}{ $k->[0] }{ $k->[1] }[1] == 1 ) {
+            } elsif ($self->{status_code}{ $k->[0] }{ $k->[1] } == 334 and $self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'AUTH' and $self->{stage}{ $k->[0] }{ $k->[1] }[1] >= 1 ) {
                  $self->_AUTH($k);
-            } elsif ($self->{status_code}{ $k->[0] }{ $k->[1] } == 235 and $self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'AUTH' and $self->{stage}{ $k->[0] }{ $k->[1] }[1] == 1 ) {
+            } elsif ($self->{status_code}{ $k->[0] }{ $k->[1] } == 235 and $self->{stage}{ $k->[0] }{ $k->[1] }[0] eq 'AUTH' and $self->{stage}{ $k->[0] }{ $k->[1] }[1] >= 1 ) {
                  $self->{stage}{ $k->[0] }{ $k->[1] }=['MAIL',0];
             }
             
@@ -843,4 +872,39 @@ sub _STRFTIME {
 
 }
 
+
+sub _MKDIRF {
+    my $self=shift;
+    my $path=shift;
+
+    my $sep=0;
+    my $np2='';
+
+    if ($path=~s!^(\w\:|)\/!!s) {
+    	$np2=''.($1||'');
+    } else {
+	$sep=1;
+    }
+    my @f=split/\//,$path;
+
+    my $fl=pop(@f);
+    foreach my $f (@f) {
+	if ($sep == 0) {
+            $np2.='/'.$f;
+	} else {
+            $np2.=$f;
+	    $sep=0;
+	}
+
+         #print "DIR($np2)\n";
+         if (!(-e $np2)) {
+            #print "GOOD\n";
+            my $mk=mkdir($np2);
+            #print "MK($mk)\n";
+         }
+    }
+    
+}
+
+
 1;
\ No newline at end of file
