@@ -11,15 +11,15 @@ use AnyEvent::Socket;
 
 =head1 NAME
 
-Net::SMTP::Bulk::Coro - NonBlocking batch SMTP using Net::SMTP interface
+Net::SMTP::Bulk::Coro - NonBlocking batch SMTP using Net::SMTP interface via Coro+AnyEvent
 
 =head1 VERSION
 
-Version 0.20
+Version 0.21
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 
 =head1 SYNOPSIS
@@ -506,9 +506,11 @@ sub _PREPARE {
        
         foreach my $t ( 0..$self->{threads}{ $new{Host} } ) {
             if ( exists($self->{debug_path}) ) {
-                my $path=''.$self->{debug_path};
+                my $path=$self->_STRFTIME(''.$self->{debug_path},time);
                 $path=~s/\[HOST\]/$new{Host}/gs;
                 $path=~s/\[THREAD\]/$t/gs;
+                      
+                $self->_MKDIRF($path);
                 open( $self->{debug_fh}{ $new{Host}.':'.$t } , '>>'.$path );
                 binmode( $self->{debug_fh}{ $new{Host}.':'.$t } , ':utf8' );
             }
@@ -896,6 +898,39 @@ sub _STRFTIME {
 
 }
 
+sub _MKDIRF {
+    my $self=shift;
+    my $path=shift;
+
+    my $sep=0;
+    my $np2='';
+
+    if ($path=~s!^(\w\:|)\/!!s) {
+    	$np2=''.($1||'');
+    } else {
+	$sep=1;
+    }
+    my @f=split/\//,$path;
+
+    my $fl=pop(@f);
+    foreach my $f (@f) {
+	if ($sep == 0) {
+            $np2.='/'.$f;
+	} else {
+            $np2.=$f;
+	    $sep=0;
+	}
+
+         #print "DIR($np2)\n";
+         if (!(-e $np2)) {
+            #print "GOOD\n";
+            my $mk=mkdir($np2);
+            #print "MK($mk)\n";
+         }
+    }
+    
+}
+
 
 
 =head1 AUTHOR
